@@ -2,6 +2,7 @@ package Net::Braintree::Gateway;
 
 use Net::Braintree::AddressGateway;
 use Net::Braintree::CreditCardGateway;
+use Net::Braintree::CreditCardVerificationGateway;
 use Net::Braintree::CustomerGateway;
 use Net::Braintree::SettlementBatchSummaryGateway;
 use Net::Braintree::SubscriptionGateway;
@@ -24,6 +25,11 @@ has 'credit_card' => (is => 'ro', lazy => 1, default => sub {
   Net::Braintree::CreditCardGateway->new(gateway => $self);
 });
 
+has 'credit_card_verification' => (is => 'ro', lazy => 1, default => sub {
+  my $self = shift;
+  Net::Braintree::CreditCardVerificationGateway->new(gateway => $self);
+});
+
 has 'customer' => (is => 'ro', lazy => 1, default => sub {
   my $self = shift;
   Net::Braintree::CustomerGateway->new(gateway => $self);
